@@ -23,7 +23,11 @@ def generate_cmds(startcmd,endCmd):
 fm_data={
         'Decimal':{
             'type':'decimal',
-            'default':Decimal('0.0')
+            'default':Decimal('0.00000'),
+            },
+        'decimal.decimal':{
+            'type':'decimal.decimal',
+            'default':Decimal('0.00000'),
             },
         'Name':{
             'type':'str',
@@ -155,6 +159,13 @@ def FormBuilderMkText(text,data,passThru=[],PassThru=True,alternative_false=None
                     value=float(text)
                 except Exception as e:
                     return 'd'
+        elif data.lower() in ['decimal.decimal','dec.dec']:
+            try:
+                value=Decimal(text).quantize(Decimal('0.0000'))
+                return value
+            except Exception as e:
+                print(e)
+                return Decimal('0.0000')
         elif data.lower() in ['decimal','dec']:
             try:
                 getcontext().prec=3
