@@ -1,5 +1,5 @@
 from . import *
-
+from radboy.DayLog.BhTrSa.bhtrsaa import *
 
 class PhoneBookUi:
 	def list_uids_names(self):
@@ -384,6 +384,11 @@ class PhoneBookUi:
 				'desc':"edit phone name and phone uid",
 				'exec':lambda self=self:self.edit_rcp(),
 			},
+			uuid1():{
+				'cmds':generate_cmds(startcmd=['bhtrsa','business hours tax rates scheduled and appointments'],endCmd=['',]),
+				'desc':"Business Hours, Tax Rates, Scheduled and Appointments {Fore.orange_red_1}[Indirectly Related]{Style.reset}",
+				'exec':BhTrSa_Gui,
+			},
 		}
 
 		htext=[]
